TypedResponse

Struct TypedResponse 

pub struct TypedResponse<T, E> { /* private fields */ }
Holds raw response body, while remembering desired shape of the success (T) and failure (E) variants.

Implementations

Source

impl<T, E> TypedResponse<T, E>

pub fn try_from_response(response: Response) -> Result<Self>

Converts reqwest::blocking::Response into TypedResponse<T, E>

pub fn bytes(&self) -> &Bytes

Access the raw HTTP response as bytes

pub fn text(&self) -> Cow<'_, str>

Access the raw HTTP response body as text

pub fn into_json(self) -> Result<Value, Value>

Convert this response into Result<serde_json::Value, serde_json::Value> where Ok and Err variants are based on the original HTTP Status In case the body is not a valid JSON by itself it creates a JSON object with deserialization error as a string content.

pub fn into_result(self) -> Result<T, E>

Convert this response into Result<T, E> where Ok and Err variants are based on the original HTTP Status and type parameters. In case of JSON deserialization error it will be converted into E.